@@ -1,10 +1,12 @@
 require 'uri'
 
 Puppet::Type.newtype(:yumrepo) do
-  @doc = "The client-side description of a yum repository. Repository
-    configurations are found by parsing `/etc/yum.conf` and
-    the files indicated by the `reposdir` option in that file
-    (see `yum.conf(5)` for details).
+  @doc = <<-'EOT'
+    @summary The client-side description of a yum repository.
+
+    Repository configurations are found by parsing `/etc/yum.conf` and the files
+    indicated by the `reposdir` option in that file (see `yum.conf(5)` for
+    details).
 
     Most parameters are identical to the ones documented
     in the `yum.conf(5)` man page.
@@ -13,12 +15,14 @@ Puppet::Type.newtype(:yumrepo) do
     are not supported. This type does not attempt to read or verify the
     existence of files listed in the `include` attribute."
 
+  EOT
+
   # Ensure yumrepos can be removed too.
   ensurable
   # Doc string for properties that can be made 'absent'
   ABSENT_DOC = 'Set this to `absent` to remove it from the file completely.'.freeze
   # False can be false/0/no and True can be true/1/yes in yum.
-  YUM_BOOLEAN = %r{^(true|false|0|1|no|yes)$}
+  YUM_BOOLEAN = %r{^(true|false|0|1|no|yes)$}.freeze
   YUM_BOOLEAN_DOC = 'Valid values are: false/0/no or true/1/yes.'.freeze
 
   # Common munge logic for YUM_BOOLEAN values. Munges for two requirements:
@@ -204,6 +208,15 @@ Puppet::Type.newtype(:yumrepo) do
     munge(&munge_yum_bool)
   end
 
+  newproperty(:module_hotfixes) do
+    desc "Whether packages from this repo can be installed into modules.
+      #{YUM_BOOLEAN_DOC}
+      #{ABSENT_DOC}"
+
+    newvalues(YUM_BOOLEAN, :absent)
+    munge(&munge_yum_bool)
+  end
+
   newproperty(:failovermethod) do
     desc "The failover method for this repository; should be either
       `roundrobin` or `priority`. #{ABSENT_DOC}"
@@ -310,7 +323,7 @@ Puppet::Type.newtype(:yumrepo) do
 
     newvalues(%r{.*}, :absent)
     validate do |value|
-      next if value.to_s =~ %r{^(absent|_none_)$}
+      next if %r{^(absent|_none_)$}.match?(value.to_s)
       next if value.to_s.empty? && Facter.value(:operatingsystemmajrelease).to_i >= 8
 
       parsed = URI.parse(value)
@@ -441,7 +454,7 @@ Puppet::Type.newtype(:yumrepo) do
 
   private
 
-  def set_sensitive_parameters(sensitive_parameters) # rubocop:disable Style/AccessorMethodName
+  def set_sensitive_parameters(sensitive_parameters)
     parameter(:password).sensitive = true if parameter(:password)
     parameter(:proxy_password).sensitive = true if parameter(:proxy_password)
     super(sensitive_parameters)
