@@ -37,9 +37,11 @@ Puppet::Type.type(:zpool).provide(:zpool) do
         sym = :spare
       when 'logs'
         sym = :log
+      when 'cache'
+        sym = :cache
       when %r{^mirror|^raidz1|^raidz2}
         sym = (value =~ %r{^mirror}) ? :mirror : :raidz
-        pool[:raid_parity] = 'raidz2' if value =~ %r{^raidz2}
+        pool[:raid_parity] = 'raidz2' if %r{^raidz2}.match?(value)
       else
         # get full drive name if the value is a partition (Linux only)
         tmp << if Facter.value(:kernel) == 'Linux' && value =~ %r{/dev/(:?[a-z]+1|disk/by-id/.+-part1)$}
@@ -59,8 +61,6 @@ Puppet::Type.type(:zpool).provide(:zpool) do
     pool
   end
 
-  # rubocop:disable Style/AccessorMethodName
-  # rubocop:disable Style/NumericPredicate
   def get_pool_data
     # https://docs.oracle.com/cd/E19082-01/817-2271/gbcve/index.html
     # we could also use zpool iostat -v mypool for a (little bit) cleaner output
@@ -133,7 +133,7 @@ Puppet::Type.type(:zpool).provide(:zpool) do
   end
 
   def create
-    zpool(*([:create] + add_pool_properties + [@resource[:pool]] + build_vdevs + build_named('spare') + build_named('log')))
+    zpool(*([:create] + add_pool_properties + [@resource[:pool]] + build_vdevs + build_named('spare') + build_named('log') + build_named('cache')))
   end
 
   def destroy
@@ -148,7 +148,7 @@ Puppet::Type.type(:zpool).provide(:zpool) do
     end
   end
 
-  [:disk, :mirror, :raidz, :log, :spare].each do |field|
+  [:disk, :mirror, :raidz, :log, :spare, :cache].each do |field|
     define_method(field) do
       current_pool[field]
     end
@@ -173,7 +173,7 @@ Puppet::Type.type(:zpool).provide(:zpool) do
   # as ashift is linux only.
   # see lib/puppet/provider/zfs/zfs.rb
 
-  PARAMETER_UNSET_OR_NOT_AVAILABLE = '-'.freeze
+  PARAMETER_UNSET_OR_NOT_AVAILABLE = '-'.freeze unless defined? PARAMETER_UNSET_OR_NOT_AVAILABLE
 
   define_method(:ashift) do
     begin
