@@ -1,4 +1,4 @@
-require 'puppet/application/face_base'
+require_relative '../../puppet/application/face_base'
 
 class Puppet::Application::Module < Puppet::Application::FaceBase
 end
