@@ -1,5 +1,5 @@
-require 'puppet/external/dot'
-require 'puppet/relationship'
+require_relative '../../puppet/external/dot'
+require_relative '../../puppet/relationship'
 require 'set'
 
 # A hopefully-faster graph class to replace the use of GRATR.
@@ -38,11 +38,12 @@ class Puppet::Graph::SimpleGraph
     @downstream_from.clear
   end
 
-  # Which resources depend upon the given resource.
+  # Which resources the given resource depends on.
   def dependencies(resource)
     vertex?(resource) ? upstream_from_vertex(resource).keys : []
   end
 
+  # Which resources depend upon the given resource.
   def dependents(resource)
     vertex?(resource) ? downstream_from_vertex(resource).keys : []
   end
@@ -133,11 +134,12 @@ class Puppet::Graph::SimpleGraph
         else
           if s[:lowlink][vertex] == s[:index][vertex] then
             this_scc = []
-            begin
+            loop do
               top = s[:stack].pop
               s[:seen][top] = false
               this_scc << top
-            end until top == vertex
+              break if top == vertex
+            end
             s[:scc] << this_scc
           end
           recur.pop               # done with this node, finally.
@@ -438,7 +440,7 @@ class Puppet::Graph::SimpleGraph
   # rdot.rb. If an edge or vertex label is a kind of Hash then the keys
   # which match +dot+ properties will be used as well.
   def to_dot_graph(params = {})
-    params['name'] ||= self.class.name.gsub(/:/,'_')
+    params['name'] ||= self.class.name.tr(':','_')
     fontsize   = params['fontsize'] ? params['fontsize'] : '8'
     graph      = (directed? ? DOT::DOTDigraph : DOT::DOTSubgraph).new(params)
     edge_klass = directed? ? DOT::DOTDirectedEdge : DOT::DOTEdge
