@@ -1,5 +1,5 @@
-require 'puppet/indirector/terminus'
-require 'puppet/util'
+require_relative '../../puppet/indirector/terminus'
+require_relative '../../puppet/util'
 
 # The base class for JSON indirection terminus implementations.
 #
@@ -41,12 +41,16 @@ class Puppet::Indirector::JSON < Puppet::Indirector::Terminus
       raise ArgumentError, _("invalid key")
     end
 
-    base = Puppet.run_mode.server? ? Puppet[:server_datadir] : Puppet[:client_datadir]
+    base = data_dir
     File.join(base, self.class.indirection_name.to_s, name.to_s + ext)
   end
 
   private
 
+  def data_dir()
+    Puppet.run_mode.server? ? Puppet[:server_datadir] : Puppet[:client_datadir]
+  end
+
   def load_json_from_file(file, key)
     json = nil
 
